utils::globalVariables(c(
  # pipe
  ".",
  #
  # nesting
  "data",
  #
  # nycflights13
  "airlines",
  "airports",
  "carrier",
  "distance",
  "faa",
  "flights",
  "planes",
  "tailnum",
  "weather",
  "time_hour",
  #
  # dm
  "any_na",
  "arrange_col",
  "candidate",
  "child_fk_cols",
  "child_table",
  "colname",
  "color",
  "cols",
  "column",
  "columns",
  "constraint",
  "day",
  "dest",
  "df",
  "display",
  "filter_expr",
  "filters",
  "fks",
  "full_type",
  "indexes",
  "into",
  "is_key",
  "key",
  "key_fk",
  "col_tracker_zoom",
  "kind",
  "mismatch_or_null",
  "name",
  "need_ref",
  "new_display",
  "new_name",
  "old",
  "origin",
  "parent",
  "parent_key_cols",
  "parent_table",
  "pk",
  "pk_col",
  "pks",
  "problem",
  "ref",
  "ref_col",
  "ref_column",
  "ref_table",
  "remote_name",
  "renames",
  "schema",
  "schema_name",
  "source_name",
  "sub_text",
  "t1",
  "t1_name",
  "t2",
  "t2_name",
  "table_name",
  "tbl_name",
  "tbls",
  "text",
  "type",
  "unique_indexes",
  "value",
  "values",
  "why",
  "zoom",
  "zoomed",
  "extra",
  "on_delete",
  #
  # financial
  "account_id",
  "accounts",
  "cards",
  "client_id",
  "clients",
  "disp_id",
  "disps",
  "district_id",
  "districts",
  "loans",
  "orders",
  "trans",
  #
  # pixarfilms
  "pixar_films",
  "pixar_people",
  "academy",
  "box_office",
  "genres",
  "public_response",
  "film",
  "role_type",
  "award_type",
  "genre"
))
